#
# spec file for package lua-cjson
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua54
%define mod_name cjson
Version:        2.1.0.14
Release:        1.1
Summary:        Lua JSON Encoding/Decoding
License:        MIT
URL:            https://github.com/openresty/lua-cjson
Source:         https://github.com/openresty/lua-cjson/archive/refs/tags/%{version}.tar.gz
# PATCH-FIX-UPSTREAM test_environment.patch gh#mpx/lua-cjson#75 mcepl@suse.com
# Make it possible for tests to be influenced by the variables
Patch0:         test_environment.patch
BuildRequires:  lua-macros
BuildRequires:  %{flavor}-devel
Requires:       %{flavor}
BuildRequires:  %{flavor}-luarocks
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
This is the Lua extension package for JSON encoding/decoding.

%prep
%autosetup -p1 -n lua-%{mod_name}-%{version}

%build
export CFLAGS="%{optflags}"
%cmake \
    -H.. -DCMAKE_C_FLAGS="%{optflags}" \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DCMAKE_VERBOSE_MAKEFILE=ON -DCMAKE_COLOR_MAKEFILE=OFF \
    -DBUILD_STATIC_LIBS=OFF -DCMAKE_INSTALL_DO_STRIP=OFF \
    -DBUILD_SHARED_LIBS=ON \
    -DLUA_INCLUDE_DIR:PATH="%{lua_incdir}"
find ..

make %{?_make_output_sync} %{?_smp_mflags} \
    CC="gcc" \
    PREFIX="%{_prefix}" \
    LUA_INCLUDE_DIR=%{lua_incdir}

%install
mkdir -p -m 755 \
    %{buildroot}%{lua_archdir} \
    %{buildroot}%{lua_noarchdir}/cjson
install -m755 build/cjson.so %{buildroot}%{lua_archdir}/
install -m644 lua/cjson/util.lua %{buildroot}%{lua_noarchdir}/cjson/

%check
rm -rf build
export CFLAGS="%{optflags}" PREFIX="%{_prefix}" SKIP_CMAKE=1 \
    LUA_INCLUDE_DIR="%{lua_incdir}" LUA_CMODULE_DIR="%{lua_archdir}" LUA_MODULE_DIR="%{lua_noarchdir}"
./runtests.sh

%files
%{lua_archdir}/cjson.so
%dir %{lua_noarchdir}/cjson
%{lua_noarchdir}/cjson/util.lua

%changelog
* Wed Jul 23 2025 Matej Cepl <mcepl@cepl.eu>
- Switch upstream from the dead one
  (http://www.kyne.com.au/~mark/software/lua-cjson.php) to
  https://github.com/openresty/lua-cjson
- Update 2.1.0.14:
  - doc: added doc for encode_skip_unsupported_value_types.
- Update 2.1.0.13:
  - Bugfix: Lua cjson integer overflow issues (CVE-2022-24834)
    (#94)
- Update 2.1.0.11:
  - add lua 5.4 to test suite
- Update to 2.1.0.9:
  - Support for Lua 5.2+ Update test suite to GitHub Actions.
  - Matrix for Lua 5.1, 5.2, 5.3, luajit master and luajit
    openresty branch, clang and gcc
- Update 2.1.0.8rc1:
  - feature: add option to disable forward slash escaping
- Update 2.1.0.7rc1:
  - feature: ported to the ARM64 platform by masking off the
    bits higher than 47-bit in the lightud.
- Update 2.1.0.6rc2:
  - bugfix: fixed the C compiler warning "SO C90 forbids mixed
    declarations and code" on older operating systems.
- Update 2.1.0.6rc1:
  - feature: set cjson.array_mt on decoded
    JSON arrays; this can be turned on via
    cjson.decode_array_with_array_mt(true). off by default.
- Update 2.1.0.5:
  - bugfix: conditionally build luaL_setfuncs() function as the
    latest LuaJIT v2.1 already includes it. fixes #21.
- Update 2.1.0.4:
  - travis-ci: added valgrind testing mode as well.
- Update 2.1.0.3rc2:
  - fixed the warning "inline function ‘fpconv_init’ declared
    but never defined" from gcc.
- Update 2.1.0.3rc1:
  - Makefile: removed the slash (/) after $(DESTDIR) so as
    to support empty DESTDIR and relative path values in the
    following variable.
- Update 2.1.0.3:
  - feature: now we allow up to 16 decimal places in JSON
    number encoding via cjson.encode_number_precision(); thanks
    lordnynex for the patch in #4.
  - Test cases for changing precision
- Update 2.1.0.2:
  - bugfix: the Makefile had a bug that overwrites existing
    cjson.so file in place which could cause already running
    nginx workers to crash. thanks ywsample for the report.
- Update 2.1.0.1:
  - feature: applied Jiale Zhi's patch to add the new config
    function encode_empty_table_as_object so that we can encode
    empty Lua tables into empty JSON arrays.
* Thu Jan 26 2023 Michal Suchanek <msuchanek@suse.de>
- Opencode %%make_build to prevent build failure when not defined.
* Sat Feb 13 2021 Matej Cepl <mcepl@suse.com>
- Make tests work (a little bit, gh#mpx/lua-cjson#75) by adding
  test_environment.patch.
* Fri Jan 29 2021 Matej Cepl <mcepl@suse.com>
- Initial packaging of cjson 2.1.0.
